# AutoForwarding

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**disposition** | **str** | The state that a message should be left in after it has been forwarded. | [optional] 
**email_address** | **str** | Email address to which all incoming messages are forwarded. This email address must be a verified member of the forwarding addresses. | [optional] 
**enabled** | **bool** | Whether all incoming mail is automatically forwarded to another address. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

